@@ -22,7 +22,7 @@ def plot_cost_dist(cost_trains, cost_tests, cost_tests_std, title=" "):
 
     """
     rc('font', **{'family': 'sans-serif', 'sans-serif': ['Helvetica'], 'size': 13})
-    rc('text', usetex=True)
+    rc('text', usetex=False)
     fig, ax = plt.subplots(dpi=200)
     plt.hist(cost_trains, label=r'$\rm{Training}$', bins=40, range=(0, 5 * cost_tests_std), alpha=0.4)
     plt.hist(cost_tests, label=r'$\rm{Validation}$', bins=40, range=(0, 5 * cost_tests_std), alpha=0.4)
